Pyrone markup language for writing articles

## Markup

Pyrone uses Markdown based markup language, it supports complete core Markdown elements set and some additional features (footnotes and pictures from internal storage).
Please consult official Markdown syntax documentation for complete language reference. In paragraphs below we are describing most used language construction.

## Basic markup

Use empty line to split text into paragraphs. | ⇒ | Use empty line to split text into paragraphs.

# This is a first level header ## Second level #### Fourth ###### Sixth (there is no 7th level though) | ⇒ | # This is a first level header ## Second level #### Fourth ###### Sixth (there is no 7th level though)

*Italic* and **bold** font. Monospaced font should be wrapped in `backticks`. | ⇒ | Italic and bold font. Monospaced font should be wrapped in `backticks`.

* simple list * each item on a new line prepended by asterisk * indented list item * and another one | ⇒ | simple list each item on a new line prepended by asterisk indented list item and another one

1. numbered list 1. put number followed by period at the beginning of each line 666. you can use any number, it doesn't affect resulting text | ⇒ | numbered list put number followed by period at the beginning of each line you can use any number, it doesn't affect resulting text

You can also use [hyperlinks](http://example.com). | ⇒ | You can also use hyperlinks.

## Extended markup

You can also use footnotes[^1]! [^1]: Really! | ⇒ | You can also use footnotes1! 1. Really ↩

Use construction “!![ALT-TEXT](FILENAME)” to insert full-sized image from the storage. You can also insert reduced image that fits into the page: “!![ALT-TEXT](FILENAME\m)” (just add “\m” suffix to filename). | ⇒ | Use construction “” to insert full-sized image from the storage. You can also insert reduced image that fits into the page: “” (just add “\m” suffix to filename).

## Splitting long articles

You can split large article into two parts using construction <cut>. After rendering only the text before <cut> (“preview”) will be displayed in the articles list and after that preview hyperlink pointing to complete article will be place.